@@ -4,15 +4,16 @@ from tala import model
 from tala.model.error import DomainError
 from tala.model.move import ICMMove
 from tala.model.proposition import Proposition, PredicateProposition
-from tala.model.question import Question, WhQuestion  # noqa
-from tala.model.goal import Perform, Resolve  # noqa
-from tala.model.predicate import Predicate  # noqa
 from tala.model.action import Action
-from tala.model.condition import Condition, create_condition  # noqa
 from tala.model.semantic_object import SemanticObject, OntologySpecificSemanticObject, SemanticObjectWithContent
 from tala.utils.as_semantic_expression import AsSemanticExpressionMixin
 from tala.utils.unicodify import unicodify
 from tala.utils.json_api import JSONAPIObject, get_attribute
+#  These are imported so that they are available in "globals()" for retrieval in PlanItem.create_from_json_api_data()
+from tala.model.question import Question, WhQuestion  # noqa
+from tala.model.goal import Perform, Resolve  # noqa
+from tala.model.condition import Condition  # noqa
+from tala.model.predicate import Predicate  # noqa
 
 TYPE_RESPOND = "respond"
 TYPE_GREET = "greet"
@@ -230,19 +231,11 @@ class Assume(PlanItemWithSemanticContent):
         PlanItemWithSemanticContent.__init__(self, TYPE_ASSUME, content=content)
 
 
-class AssumePlanItem(Assume):
-    pass
-
-
 class AssumeShared(PlanItemWithSemanticContent):
     def __init__(self, content):
         PlanItemWithSemanticContent.__init__(self, TYPE_ASSUME_SHARED, content=content)
 
 
-class AssumeSharedPlanItem(AssumeShared):
-    pass
-
-
 class AssumeIssue(PlanItemWithSemanticContent):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -279,10 +272,6 @@ class AssumeIssue(PlanItemWithSemanticContent):
         return ["issue"]
 
 
-class AssumeIssuePlanItem(AssumeIssue):
-    pass
-
-
 class Respond(PlanItemWithSemanticContent):
     def __init__(self, content):
         PlanItemWithSemanticContent.__init__(self, TYPE_RESPOND, content=content)
@@ -291,20 +280,12 @@ class Respond(PlanItemWithSemanticContent):
         return True
 
 
-class RespondPlanItem(Respond):
-    pass
-
-
 class Do(PlanItemWithSemanticContent):
     def __init__(self, action):
         assert action.is_action()
         PlanItemWithSemanticContent.__init__(self, TYPE_DO, content=action)
 
 
-class DoPlanItem(Do):
-    pass
-
-
 class PlanItemWithoutContent(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, _data, _included):
@@ -316,28 +297,16 @@ class Quit(PlanItemWithoutContent):
         PlanItem.__init__(self, TYPE_QUIT)
 
 
-class QuitPlanItem(Quit):
-    pass
-
-
 class Mute(PlanItemWithoutContent):
     def __init__(self):
         PlanItem.__init__(self, TYPE_MUTE)
 
 
-class MutePlanItem(Mute):
-    pass
-
-
 class Unmute(PlanItemWithoutContent):
     def __init__(self):
         PlanItem.__init__(self, TYPE_UNMUTE)
 
 
-class UnmutePlanItem(Unmute):
-    pass
-
-
 class Greet(PlanItemWithoutContent):
     def __init__(self):
         PlanItem.__init__(self, TYPE_GREET)
@@ -346,28 +315,16 @@ class Greet(PlanItemWithoutContent):
         return True
 
 
-class GreetPlanItem(Greet):
-    pass
-
-
 class RespondToInsult(PlanItemWithoutContent):
     def __init__(self):
         PlanItem.__init__(self, TYPE_RESPOND_TO_INSULT)
 
 
-class RespondToInsultPlanItem(RespondToInsult):
-    pass
-
-
 class RespondToThankYou(PlanItemWithoutContent):
     def __init__(self):
         PlanItem.__init__(self, TYPE_RESPOND_TO_THANK_YOU)
 
 
-class RespondToThankYouPlanItem(RespondToThankYou):
-    pass
-
-
 class EmitICM(PlanItemWithSemanticContent):
     def __init__(self, icm_move):
         PlanItemWithSemanticContent.__init__(self, TYPE_EMIT_ICM, content=icm_move)
@@ -415,10 +372,6 @@ class Bind(PlanItemWithSemanticContent):
         return ["question"]
 
 
-class BindPlanItem(Bind):
-    pass
-
-
 class JumpTo(PlanItemWithSemanticContent):
     def __init__(self, content):
         PlanItemWithSemanticContent.__init__(self, TYPE_JUMPTO, content=content)
@@ -428,10 +381,6 @@ class JumpTo(PlanItemWithSemanticContent):
         return self.content
 
 
-class JumpToPlanItem(JumpTo):
-    pass
-
-
 class IfThenElse(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -543,37 +492,21 @@ class ForgetAll(PlanItem):
         PlanItem.__init__(self, TYPE_FORGET_ALL)
 
 
-class ForgetAllPlanItem(ForgetAll):
-    pass
-
-
 class Forget(PlanItemWithSemanticContent):
     def __init__(self, predicate_or_proposition):
         PlanItemWithSemanticContent.__init__(self, TYPE_FORGET, predicate_or_proposition)
 
 
-class ForgetPlanItem(Forget):
-    pass
-
-
 class ForgetShared(PlanItemWithSemanticContent):
     def __init__(self, predicate_or_proposition):
         PlanItemWithSemanticContent.__init__(self, TYPE_FORGET_SHARED, predicate_or_proposition)
 
 
-class ForgetSharedPlanItem(ForgetShared):
-    pass
-
-
 class ForgetIssue(PlanItemWithSemanticContent):
     def __init__(self, issue):
         PlanItemWithSemanticContent.__init__(self, TYPE_FORGET_ISSUE, issue)
 
 
-class ForgetIssuePlanItem(ForgetIssue):
-    pass
-
-
 class MinResultsNotSupportedException(Exception):
     pass
 
@@ -644,10 +577,6 @@ class InvokeQuery(PlanItemWithSemanticContent):
         return ["question"]
 
 
-class InvokeQueryPlanItem(InvokeQuery):
-    pass
-
-
 class InvokeServiceQuery(InvokeQuery):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -663,10 +592,6 @@ class InvokeServiceQuery(InvokeQuery):
         InvokeQuery.__init__(self, issue, TYPE_INVOKE_SERVICE_QUERY, min_results, max_results)
 
 
-class InvokeServiceQueryPlanItem(InvokeServiceQuery):
-    pass
-
-
 class InvokeDomainQuery(InvokeQuery):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -692,21 +617,17 @@ class InvokeDomainQuery(InvokeQuery):
         return ["question"]
 
 
-class InvokeDomainQueryPlanItem(InvokeDomainQuery):
-    pass
-
-
 class InvokeServiceAction(PlanItem, OntologySpecificSemanticObject):
     INTERROGATIVE = "INTERROGATIVE"
     ASSERTIVE = "ASSERTIVE"
 
     @classmethod
-    def create_from_json_api_data(cls, data, included):
-        ontology_name = data["attributes"]["ontology_name"]
-        service_action = data["attributes"]["service_action"]
-        preconfirm = data["attributes"]["preconfirm"]
-        postconfirm = data["attributes"]["postconfirm"]
-        should_downdate_plan = data["attributes"]["_downdate_plan"]
+    def create_from_json_api_data(cls, plan_item_data, included):
+        ontology_name = plan_item_data["attributes"]["ontology_name"]
+        service_action = plan_item_data["attributes"]["service_action"]
+        preconfirm = plan_item_data["attributes"]["preconfirm"]
+        postconfirm = plan_item_data["attributes"]["postconfirm"]
+        should_downdate_plan = plan_item_data["attributes"]["_downdate_plan"]
         return cls(ontology_name, service_action, preconfirm, postconfirm, should_downdate_plan)
 
     def __init__(self, ontology_name, service_action, preconfirm=None, postconfirm=False, downdate_plan=True):
@@ -733,7 +654,7 @@ class InvokeServiceAction(PlanItem, OntologySpecificSemanticObject):
         return self._downdate_plan
 
     def __eq__(self, other):
-        return super(InvokeServiceAction, self).__eq__(other) \
+        return super().__eq__(other) \
             and other.get_service_action() == self.get_service_action() \
             and other.has_interrogative_preconfirmation() == self.has_interrogative_preconfirmation() \
             and other.has_assertive_preconfirmation() == self.has_assertive_preconfirmation() \
@@ -771,10 +692,6 @@ class InvokeServiceAction(PlanItem, OntologySpecificSemanticObject):
         return ["service_action", "ontology_name", "preconfirm", "postconfirm", "_downdate_plan", "type_"]
 
 
-class InvokeServiceActionPlanItem(InvokeServiceAction):
-    pass
-
-
 class ServiceReport(PlanItemWithSemanticContent):
     def __init__(self, result_proposition):
         PlanItemWithSemanticContent.__init__(self, TYPE_SERVICE_REPORT, result_proposition)
@@ -783,10 +700,6 @@ class ServiceReport(PlanItemWithSemanticContent):
         return self._content.type_ == Proposition.SERVICE_RESULT
 
 
-class ServiceReportPlanItem(ServiceReport):
-    pass
-
-
 class ActionReport(PlanItemWithSemanticContent):
     def __init__(self, result_proposition):
         PlanItemWithSemanticContent.__init__(self, TYPE_ACTION_REPORT, result_proposition)
@@ -795,10 +708,6 @@ class ActionReport(PlanItemWithSemanticContent):
         return self._content.type_ in [Proposition.SERVICE_RESULT, Proposition.ACTION_STATUS]
 
 
-class ActionReportPlanItem(ActionReport):
-    pass
-
-
 class QuestionReport(PlanItemWithSemanticContent):
     def __init__(self, result_proposition):
         PlanItemWithSemanticContent.__init__(self, TYPE_QUESTION_REPORT, result_proposition)
@@ -807,19 +716,11 @@ class QuestionReport(PlanItemWithSemanticContent):
         return self._content.type_ == Proposition.QUESTION_STATUS
 
 
-class QuestionReportPlanItem(QuestionReport):
-    pass
-
-
 class EmitMove(PlanItemWithSemanticContent):
     def __init__(self, move):
         PlanItemWithSemanticContent.__init__(self, TYPE_EMIT_MOVE, move)
 
 
-class EmitMovePlanItem(EmitMove):
-    pass
-
-
 class Handle(PlanItem, OntologySpecificSemanticObject):
     def __init__(self, ontology_name, service_action):
         PlanItem.__init__(self, TYPE_HANDLE)
@@ -848,10 +749,6 @@ class Handle(PlanItem, OntologySpecificSemanticObject):
         return obj.as_dict
 
 
-class HandlePlanItem(Handle):
-    pass
-
-
 class UnexpectedLogLevelException(Exception):
     pass
 
@@ -901,10 +798,6 @@ class Log(PlanItem):
         return ["message", "level"]
 
 
-class LogPlanItem(Log):
-    pass
-
-
 class GetDone(PlanItemWithSemanticContent):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -941,10 +834,6 @@ class GetDone(PlanItemWithSemanticContent):
         return ["step"]
 
 
-class GetDonePlanItem(GetDone):
-    pass
-
-
 class GoalPerformed(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -975,10 +864,6 @@ class GoalPerformed(PlanItem):
         return []
 
 
-class GoalPerformedPlanItem(GoalPerformed):
-    pass
-
-
 class GoalAborted(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, object_as_json, included):
@@ -1011,10 +896,6 @@ class GoalAborted(PlanItem):
         return ["reason"]
 
 
-class GoalAbortedPlanItem(GoalAborted):
-    pass
-
-
 class EndTurn(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, endturn_data, included):
@@ -1050,10 +931,6 @@ class EndTurn(PlanItem):
         return []
 
 
-class EndTurnPlanItem(EndTurn):
-    pass
-
-
 class ResetDomainQuery(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, data, included):
@@ -1091,10 +968,6 @@ class ResetDomainQuery(PlanItem):
         return ["query"]
 
 
-class ResetDomainQueryPlanItem(ResetDomainQuery):
-    pass
-
-
 class Iterate(PlanItemWithContent):
     @classmethod
     def create_from_json_api_data(cls, endturn_data, _included):
@@ -1126,10 +999,6 @@ class Iterate(PlanItemWithContent):
         return []
 
 
-class IteratePlanItem(Iterate):
-    pass
-
-
 class ChangeDDD(PlanItem):
     @classmethod
     def create_from_json_api_data(cls, data, _included):
@@ -1165,10 +1034,6 @@ class ChangeDDD(PlanItem):
         return []
 
 
-class ChangeDDDPlanItem(ChangeDDD):
-    pass
-
-
 class QuestionRaisingPlanItem(PlanItemWithSemanticContent):
     SOURCE_SERVICE = "service"
     SOURCE_DOMAIN = "domain"
@@ -1250,10 +1115,6 @@ class Findout(QuestionRaisingPlanItem):
         QuestionRaisingPlanItem.__init__(self, domain_name, TYPE_FINDOUT, content, allow_answer_from_pcom)
 
 
-class FindoutPlanItem(Findout):
-    pass
-
-
 class Raise(QuestionRaisingPlanItem):
     @classmethod
     def create_from_json_api_data(cls, plan_item_data, included):
@@ -1266,15 +1127,11 @@ class Raise(QuestionRaisingPlanItem):
         QuestionRaisingPlanItem.__init__(self, domain_name, TYPE_RAISE, content)
 
 
-class RaisePlanItem(Raise):
-    pass
-
-
 class UnexpectedDomainException(Exception):
     pass
 
 
-class QuestionRaisingPlanItemOfDomain(object):
+class QuestionRaisingPlanItemOfDomain:
     def __init__(self, domain, plan_item):
         if domain.name != plan_item.domain_name:
             raise UnexpectedDomainException(
